<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_419" version="2.1">
<context>
    <name>CloseConfirmDialog</name>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="61"/>
        <source>Please select your operation</source>
        <translation>Por favor, seleccione su operación</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="68"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="70"/>
        <source>Minimize to system tray</source>
        <translation>Minimizar a bandeja de sistema</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="79"/>
        <source>Do not ask again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="90"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="91"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>Footer</name>
    <message>
        <location filename="../view/footerwidget.cpp" line="290"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="291"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="292"/>
        <source>Play/Pause</source>
        <translation>Reproducir/Pausar </translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="293"/>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="294"/>
        <source>Lyrics</source>
        <translation>Letras</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="239"/>
        <source>Unknown Title</source>
        <translation>Título desconocido</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="245"/>
        <location filename="../view/footerwidget.cpp" line="536"/>
        <location filename="../view/footerwidget.cpp" line="718"/>
        <source>Unknown artist</source>
        <translation>Artista desconocido</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="295"/>
        <source>Play Mode</source>
        <translation>Modo reproducción</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="296"/>
        <source>Playlist</source>
        <translation>Lista de reproducción</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="696"/>
        <source>List Loop</source>
        <translation>Lista en bucle</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="699"/>
        <source>Single Loop</source>
        <translation>Un solo bucle</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="702"/>
        <source>Shuffle</source>
        <translation>Aleatorio</translation>
    </message>
</context>
<context>
    <name>ImportWidget</name>
    <message>
        <location filename="../view/importwidget.cpp" line="73"/>
        <source>Add folder</source>
        <translation>Añadir carpeta</translation>
    </message>
    <message>
        <location filename="../view/importwidget.cpp" line="79"/>
        <location filename="../view/importwidget.cpp" line="120"/>
        <source>Scan</source>
        <translation>Escanear</translation>
    </message>
    <message>
        <location filename="../view/importwidget.cpp" line="80"/>
        <location filename="../view/importwidget.cpp" line="121"/>
        <source>%1 music directory or drag &amp; drop music file to add music</source>
        <translation>%1 directorio de música o arrastre y suelte el archivo musical para añadir música</translation>
    </message>
    <message>
        <location filename="../view/importwidget.cpp" line="112"/>
        <source>Loading music, please wait...</source>
        <translation>Cargando música, por favor espere...</translation>
    </message>
</context>
<context>
    <name>InfoDialog</name>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="117"/>
        <source>Title:</source>
        <translation>Título: </translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="117"/>
        <source>Artist:</source>
        <translation>Artista: </translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="118"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="118"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="120"/>
        <source>Path:</source>
        <translation>Ruta de acceso:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="192"/>
        <source>Unknown artist</source>
        <translation>Artista desconocido</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="193"/>
        <source>Unknown album</source>
        <translation>Album desconocido </translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="119"/>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="119"/>
        <source>Duration:</source>
        <translation>Duración:</translation>
    </message>
</context>
<context>
    <name>LoadWidget</name>
    <message>
        <location filename="../view/loadwidget.cpp" line="43"/>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
</context>
<context>
    <name>LyricWidget</name>
    <message>
        <location filename="../view/lyricwidget.cpp" line="166"/>
        <source>Find lyrics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="170"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="175"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="180"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="213"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
</context>
<context>
    <name>MainFrame</name>
    <message>
        <location filename="../view/mainframe.cpp" line="136"/>
        <source>New playlist</source>
        <translation>Nueva lista de reproducción</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="152"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="183"/>
        <location filename="../view/mainframe.cpp" line="595"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="142"/>
        <source>Add folder</source>
        <translation>Añadir carpeta</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="147"/>
        <source>Add file</source>
        <translation>Añadir archivo</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="168"/>
        <source>Dark theme</source>
        <translation>Tema oscuro</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="254"/>
        <source>Deepin Music is a beautiful and simple music player that plays local audios. It supports viewing lyrics during playback, playing lossless audio and playlist customization, etc.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="592"/>
        <source>Play/Pause</source>
        <translation>Reproducir/Pausar </translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="593"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="739"/>
        <source>Invalid or non-existent file</source>
        <translation>Archivo no existe o es inválido</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="760"/>
        <source>Failed to import, no vaild music file found!</source>
        <translation>Error al importar, ¡ningún archivo de música fue encontrado!</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="1027"/>
        <source>All music</source>
        <translation>Toda la música</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="740"/>
        <location filename="../view/mainframe.cpp" line="765"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="690"/>
        <source>Successfully added to &quot;%1&quot;</source>
        <translation>Se agregó correctamente a &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="594"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
</context>
<context>
    <name>MusicListView</name>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="295"/>
        <source>New playlist</source>
        <translation>Nueva lista de reproducción</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="335"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="337"/>
        <source>Add to playlist</source>
        <translation>Añadir a la Lista de Reproducción</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="342"/>
        <source>Display in file manager</source>
        <translation>Mostrar en administrador de archivos</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="369"/>
        <source>Song info</source>
        <translation>Información de canción</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="425"/>
        <source>Are you sure you want to delete %1?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="427"/>
        <location filename="../view/widget/musiclistview.cpp" line="431"/>
        <source>Are you sure you want to delete the selected %1 songs?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="345"/>
        <source>Remove from playlist</source>
        <translation>Remover de la lista de reproducción </translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="346"/>
        <source>Delete from local disk</source>
        <translation>Borrar del disco local</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="365"/>
        <source>Encoding</source>
        <translation>Codificando</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="415"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="416"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="432"/>
        <source>Deleting the current song will also delete the song files contained</source>
        <translation>Al borrar la canción actual también se eliminarán los archivos musicales contenidos</translation>
    </message>
    <message>
        <location filename="../view/widget/delegate/musicitemdelegate.cpp" line="299"/>
        <source>Unknown artist</source>
        <translation>Artista desconocido</translation>
    </message>
    <message>
        <location filename="../view/widget/delegate/musicitemdelegate.cpp" line="310"/>
        <source>Unknown album</source>
        <translation>Album desconocido </translation>
    </message>
</context>
<context>
    <name>MusicListWidget</name>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="140"/>
        <source>No Music</source>
        <translation>Sin música</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="142"/>
        <source>No result found</source>
        <translation>No se ha encontrado resultado</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="174"/>
        <source>Play All</source>
        <translation>Reproducir todo</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="182"/>
        <source>Time added</source>
        <translation>Tiempo añadido</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="183"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="184"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="185"/>
        <source>Album name</source>
        <translation>Nombre del álbum</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="217"/>
        <source>Custom</source>
        <translation>Personailzar</translation>
    </message>
</context>
<context>
    <name>PlayListItem</name>
    <message>
        <location filename="../view/widget/playlistitem.cpp" line="187"/>
        <source>Are you sure you want to delete this playlist?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/widget/playlistitem.cpp" line="194"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../view/widget/playlistitem.cpp" line="193"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>PlayListView</name>
    <message>
        <location filename="../view/widget/playlistview.cpp" line="186"/>
        <location filename="../view/widget/playlistview.cpp" line="195"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../view/widget/playlistview.cpp" line="190"/>
        <location filename="../view/widget/playlistview.cpp" line="198"/>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <location filename="../view/widget/playlistview.cpp" line="191"/>
        <location filename="../view/widget/playlistview.cpp" line="202"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>PlaylistManager</name>
    <message>
        <location filename="../core/playlistmanager.cpp" line="79"/>
        <source>New playlist</source>
        <translation>Nueva lista de reproducción</translation>
    </message>
    <message>
        <location filename="../core/playlistmanager.cpp" line="135"/>
        <source>All Music</source>
        <translation>Toda la música</translation>
    </message>
    <message>
        <location filename="../core/playlistmanager.cpp" line="141"/>
        <source>My favorites</source>
        <translation>Mis favoritos</translation>
    </message>
    <message>
        <location filename="../core/playlistmanager.cpp" line="147"/>
        <source>Search result</source>
        <translation>Buscar resultado</translation>
    </message>
</context>
<context>
    <name>PlaylistWidget</name>
    <message>
        <location filename="../view/playlistwidget.cpp" line="58"/>
        <source>New playlist</source>
        <translation>Nueva lista de reproducción</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../view/mainframe.cpp" line="256"/>
        <source>Deepin Music</source>
        <translation>Reproductor Deepin</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>Deepin Music</source>
        <translation>Reproductor Deepin</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="26"/>
        <source>Minimize to system tray</source>
        <translation>Minimizar a bandeja de sistema</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="27"/>
        <source>Exit Deepin Music</source>
        <translation>Salir de Música Deepin</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="28"/>
        <source>Autoplay</source>
        <translation>Reproducción automática</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="29"/>
        <source>Enable fade in/out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="30"/>
        <source>Remember playback position</source>
        <translation>Recuerde la posición de reproducción</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="31"/>
        <source>Close Main Window</source>
        <translation>Cerrar ventana principal</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="32"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="33"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="34"/>
        <source>Shortcuts</source>
        <translation>Atajos de teclado</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="35"/>
        <source>Restore Defaults</source>
        <translation>Restaurar los valores predeterminados</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="36"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="37"/>
        <source>Play/Pause</source>
        <translation>Reproducir/Pausar </translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="38"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="39"/>
        <source>Volume down</source>
        <translation>Bajar volumen</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="40"/>
        <source>Volume up</source>
        <translation>Subir volumen</translation>
    </message>
</context>
<context>
    <name>SearchResult</name>
    <message>
        <location filename="../view/widget/searchresult.cpp" line="57"/>
        <location filename="../view/widget/searchresult.cpp" line="126"/>
        <source>Search &quot;%1&quot; in Deepin Music</source>
        <translation>Buscar &quot;%1&quot; en Deepin Music</translation>
    </message>
</context>
<context>
    <name>TitlebarWidget</name>
    <message>
        <location filename="../view/widget/titlebarwidget.cpp" line="90"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
</TS>